summaryrefslogtreecommitdiffstats
path: root/gtk2/kgtk2.c
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit16fc4daa581635fdb019aa4734fc3ff41d656d30 (patch)
tree5e905db7f3091ffc1e682995433e925cfc0edd33 /gtk2/kgtk2.c
parent3dc5583024994425d0f3bcb120fb7dd8fc9693ac (diff)
downloadkgtk-qt3-16fc4daa581635fdb019aa4734fc3ff41d656d30.tar.gz
kgtk-qt3-16fc4daa581635fdb019aa4734fc3ff41d656d30.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kgtk-qt3@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'gtk2/kgtk2.c')
-rw-r--r--gtk2/kgtk2.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/gtk2/kgtk2.c b/gtk2/kgtk2.c
index 1c97f8a..0dddab5 100644
--- a/gtk2/kgtk2.c
+++ b/gtk2/kgtk2.c
@@ -149,7 +149,7 @@ static const gchar *getAppName(const gchar *app)
const gchar *a=app ? app : kgtk_get_app_name(getpid());
gchar *slash;
/* Was the cmdline app java? if so, try to use its tqparent name - just in case
its run from a shell script, etc. - e.g. as eclipse does */
if(a && 0==strcmp(a, "java"))
a=kgtk_get_app_name(getppid());
@@ -249,7 +249,7 @@ static gboolean sendMessage(GtkWidget *widget, Operation op, GSList **res, gchar
if(widget->parent)
{
#ifdef KGTK_DEBUG
- printf("KGTK::Dialog has a tqparent!\n");
+ printf("KGTK::Dialog has a parent!\n");
#endif
xid=GDK_WINDOW_XID(gtk_widget_get_toplevel(widget->parent));
}
@@ -632,7 +632,7 @@ RowType;
static GtkWidget *
kgtk_file_chooser_dialog_new_valist (const gchar *title,
- GtkWindow *tqparent,
+ GtkWindow *parent,
GtkFileChooserAction action,
const gchar *backend,
const gchar *first_button_text,
@@ -648,8 +648,8 @@ kgtk_file_chooser_dialog_new_valist (const gchar *title,
"file-system-backend", backend,
NULL);
- if (tqparent)
- gtk_window_set_transient_for (GTK_WINDOW (result), tqparent);
+ if (parent)
+ gtk_window_set_transient_for (GTK_WINDOW (result), parent);
while (button_text)
{
@@ -1737,7 +1737,7 @@ void g_signal_stop_emission_by_name(gpointer instance, const gchar *detailed_sig
#endif
}
-GtkWidget * gtk_file_chooser_dialog_new(const gchar *title, GtkWindow *tqparent,
+GtkWidget * gtk_file_chooser_dialog_new(const gchar *title, GtkWindow *parent,
GtkFileChooserAction action, const gchar *first_button_text,
...)
{
@@ -1748,7 +1748,7 @@ GtkWidget * gtk_file_chooser_dialog_new(const gchar *title, GtkWindow *tqparent,
va_list varargs;
va_start(varargs, first_button_text);
- dlg=kgtk_file_chooser_dialog_new_valist(title, tqparent, action, NULL, first_button_text, varargs);
+ dlg=kgtk_file_chooser_dialog_new_valist(title, parent, action, NULL, first_button_text, varargs);
va_end(varargs);
#ifdef KGTK_DEBUG
@@ -149,7 +149,7 @@ static const gchar *getAppName(const gchar *app)
const gchar *a=app ? app : kgtk_get_app_name(getpid());
gchar *slash;
- /* Was the cmdline app java? if so, try to use its tqparent name - just in case
+ /* Was the cmdline app java? if so, try to use its parent name - just in case
its run from a shell script, etc. - e.g. as eclipse does */
if(a && 0==strcmp(a, "java"))